intervaltreetools.calculate_min_mean_and_max_depth_of_intervals
===============================================================

.. autofunction:: abjad.tools.intervaltreetools.calculate_min_mean_and_max_depth_of_intervals
